---
name: "\U0001F4DA Documentation/Examples"
about: Describe this issue template's purpose here.
title: "[Docs]"
labels: documentation
assignees: ''

---

# 📚 Documentation/Examples

** Is there documentation missing? **
<!-- Let us know what modules have missing or incomplete documentation -->

** Is documentation wrong? **
<!-- Let us know if you find a mistake in the documentation! -->

** Is there a feature that needs some example code? **
<!-- Let us know if we're missing any example notebooks -->

** Think you know how to fix the docs? ** (If so, we'd love a pull request from you!)

- Link to [GPyTorch documentation](https://gpytorch.readthedocs.io)
- Link to [GPyTorch examples](https://github.com/cornellius-gp/gpytorch/tree/main/examples)
